============================================================
 Urllib3 HTTP Client Pool - ``kombu.asynchronous.http.urllib3_client``
============================================================

.. contents::
    :local:
.. currentmodule:: kombu.asynchronous.http.urllib3_client

.. automodule:: kombu.asynchronous.http.urllib3_client
    :members:
    :undoc-members:
